@@ -2,9 +2,15 @@
 
 set -ex
 
+# https://bugs.launchpad.net/bugs/1828228
+ulimit -H -l unlimited 2>/dev/null || {
+	echo "test disabled for unprivileged namespaces"
+	exit 77
+}
+
 service corosync stop
 
-crm cluster init --yes --name=autopkgtest --unicast --admin-ip=127.1.1.1
+crm cluster init --yes --name=autopkgtest --unicast
 
 crm cluster geo-init --yes --clusters=autopkgtest=127.2.2.2 --tickets=ticket1
 crm resource start g-booth
@@ -12,7 +18,7 @@ sleep 5
 
 crm status
 
-crm status | grep -q admin-ip.*Started
+crm status | grep -q booth-ip.*Started
 crm status | grep -q booth-site.*Started
 
 : INFO all tests OK
